@@ -16,7 +16,7 @@ from init_helpers.custom_json import custom_dumps
 from time_tools import Timerange
 
 
-@dataclass(kw_only=True)
+@dataclass(kw_only=True, frozen=True)
 class DetectorSettings(ABC):
     rtsp_url: str
     created_at: float | None = None
