@@ -29,7 +29,7 @@ class DetectorAnalyzeResult:
     snapshot_done_at: float
     reference_image_file_ids: list[str]
     detector_requests: list[dict[str, str | float | bool | int]]
-    detector_results: list[dict[str, str | float | bool | int]]
+    detector_results: list[dict[str, str | float | bool | int | list]]
     comparison_settings: dict[str, str | float | list]
     comparison_results: list[float]
     result: float
